==> phpBB-3.1.8-deutsch_to_3.1.10-deutsch.tar.bz2: install/update/new/language/de/README.md <==
Deutsche Sprachdateien für phpBB 3.1.10
---------------------------------------
Stand: 2016-09-26

Deutsche Übersetzung durch die Übersetzer-Gruppe von phpBB.de
Siehe docs/AUTHORS für die aktuellen und die ehemaligen Mitglieder
Das aktuelle Team: https://www.phpbb.de/go/ubersetzerteam

Die Nutzungsbedingungen und die Datenschutzrichtlinie wurden zuletzt
inhaltlich in der Version für phpBB 3.0.0 vom 2007-12-13 geändert.


Lizenz
------
Diese Sprachdateien für phpBB unterliegen der GPL (siehe LICENSE).

Rechtliche Hinweise
-------------------
In diesem Paket sind teilweise auch Hinweise enthalten, die auf
rechtliche Fragestellungen Bezug nehmen. Dies gilt insbesondere für die
Nutzungsbedingungen und die Datenschutzrichtlinie. Es wurde versucht,
diese Hinweise allgemein zu halten, sie beziehen sich jedoch primär auf
deutsches Recht. Diese Regelungen sollen und können jedoch keine
rechtliche Beratung in diesen Fragen ersetzen. Sie werden daher - außer
bei vorsätzlichem oder grob fahrlässigem Verhalten - ohne Gewähr zur
Verfügung gestellt.
Es sei an dieser Stelle jedoch auf ein paar Besonderheiten hingewiesen,
deren Beachtung wir dringend empfehlen:
- durch europäisches Recht ist für die meisten Websites ein Impressum
  zwingend vorgeschrieben, das zentral zugänglich sein muss und
  Mindestangaben enthalten muss.
- Die Datenschutzrichtlinie (PRIVACY_POLICY in ucp.php) enthält
  Hinweise zum Auskunftsrecht der Nutzer. Diese Stelle sollte um einen
  Hinweis zu den Kontaktmöglichkeiten ergänzt werden.
- Änderungen an den Nutzungsbedingungen und der Datenschutzrichtlinie
  bedürfen nach höchstrichterlicher Rechtsprechung einer Zustimmung
  durch die Nutzer. Dies gilt auch bereits für den Wechsel von einer
  Vorversion auf diese Version der Sprachdateien (Hinweise zur letzten
  Änderung der relevanten Abschnitte findest du oben in dieser Datei).
  phpBB selbst enthält standardmäßig keine Funktion, um eine erneute
  Bestätigung der Nutzungsbedingungen zu erzwingen.

Fehler
------
Fehler in den deutschen Sprachdateien können unter
https://www.phpbb.de/go/3.1/sprachdateienfehler gemeldet werden.

==> phpBB-3.2.3-deutsch_to_3.2.5-deutsch.tar.bz2: install/update/new/language/de/README.md <==
Deutsche Sprachdateien für phpBB 3.2.5
--------------------------------------
Stand: 2018-12-21

Deutsche Übersetzung durch die Übersetzer-Gruppe von phpBB.de
Siehe docs/AUTHORS für die aktuellen und die ehemaligen Mitglieder
Das aktuelle Team: https://www.phpbb.de/go/ubersetzerteam

Die Nutzungsbedingungen und die Datenschutzerklärung wurden zuletzt
inhaltlich in der Version für phpBB 3.0.0 vom 2007-12-13 geändert.


Lizenz
------
Diese Sprachdateien für phpBB unterliegen der GPL (siehe LICENSE).

Rechtliche Hinweise
-------------------
In diesem Paket sind teilweise auch Hinweise enthalten, die auf
rechtliche Fragestellungen Bezug nehmen. Dies gilt insbesondere für die
Nutzungsbedingungen und die Datenschutzerklärung. Es wurde versucht,
diese Hinweise allgemein zu halten, sie beziehen sich jedoch primär auf
deutsches Recht. Diese Regelungen sollen und können jedoch keine
rechtliche Beratung in diesen Fragen ersetzen. Sie werden daher - außer
bei vorsätzlichem oder grob fahrlässigem Verhalten - ohne Gewähr zur
Verfügung gestellt.
Es sei an dieser Stelle jedoch auf ein paar Besonderheiten hingewiesen,
deren Beachtung wir dringend empfehlen:
- durch europäisches Recht ist für die meisten Websites ein Impressum
  zwingend vorgeschrieben, das zentral zugänglich sein muss und
  Mindestangaben enthalten muss.
- Die Datenschutzerklärung (PRIVACY_POLICY in ucp.php) enthält
  Hinweise zum Auskunftsrecht der Nutzer. Diese Stelle sollte um einen
  Hinweis zu den Kontaktmöglichkeiten ergänzt werden.
- Änderungen an den Nutzungsbedingungen und der Datenschutzerklärung
  bedürfen nach höchstrichterlicher Rechtsprechung einer Zustimmung
  durch die Nutzer. Dies gilt auch bereits für den Wechsel von einer
  Vorversion auf diese Version der Sprachdateien (Hinweise zur letzten
  Änderung der relevanten Abschnitte findest du oben in dieser Datei).
  phpBB selbst enthält standardmäßig keine Funktion, um eine erneute
  Bestätigung der Nutzungsbedingungen zu erzwingen.

Fehler
------
Fehler in den deutschen Sprachdateien können unter
https://www.phpbb.de/go/3.2/sprachdateienfehler gemeldet werden.
